# fatoriais

Description. 
The package fatoriais is used to:
	- Calculate the factorials of numbers from 1 to 10

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install fatoriais

```bash
pip install fatoriais
```

## Usage

```python
from fatoriais.fatorial import fatorial
fatorial(n)
```
- Replace "n" with the number you want the factorial

## Author
Enzo Camelo Vieira

## License
[MIT](https://choosealicense.com/licenses/mit/)